Welcome to stati-python's documentation!
======================================


.. image:: https://secure.travis-ci.org/GottWall/stati-python.png
	   :target: https://secure.travis-ci.org/GottWall/stati-python

Features
--------

- Redis pub/sub transport
- HTTP transport


INSTALLATION
------------

To use gottwall  use pip or easy_install:

`pip install stati-python`

or

`easy_install stati-python`


USAGE
-----



CONTRIBUTE
----------

Fork https://github.com/GottWall/stati-python/ , create commit and pull request.

